@@ -5,9 +5,9 @@ import re
 
 import traceback
 
-from zcrmsdk.src.com.zoho.api import SDKException
+from zcrmsdk.src.com.zoho.api.exception import SDKException
 
-from zcrmsdk.src.com.zoho.crm.api import Constants
+from zcrmsdk.src.com.zoho.crm.api.util.constants import Constants
 
 
 class User(object):
