@@ -1,5 +1,5 @@
+from ..variable_groups import VariableGroup
 from ..util import Model
-from ..variablegroups import VariableGroup
 
 
 class Variable(Model):
